import React from "react";
import type { Moment } from 'moment';
export interface FilterProps extends FilterContentProps {
    /** 卡片类名 */
    overlayClassName?: string;
    /** 卡片样式 */
    overlayStyle?: string;
    /** 展开行为， 可选'hover' | 'focus' | 'click' | 'contextMenu' */
    trigger?: string | string[];
    /** 筛选按钮文案，默认“筛选” */
    btnText: string;
    /** 自定义筛选按钮 */
    btnRender: React.ReactNode;
    /** 条件选择后的回调，默认失焦触发 */
    filterOk?: (filterParmas: FilterParamsType) => void;
    /** 筛选值数据 */
    items: ItemType[];
    /** 默认筛选条件字段 */
    searchFields: FilterParamsType[];
    /** 筛选结果数量 */
    total?: number;
    /** 单位 */
    unit?: string;
    filterNode?: React.ReactNode;
    /** 是否展示筛选结果及筛选条件tag */
    showSelectedTag?: boolean;
}
export declare type FieldType = 'selection' | 'string' | 'number' | 'date' | 'address' | 'org' | 'emp' | 'object';
/** 最终搜索入参类型 */
export interface FilterParamsType {
    /** 字段ID */
    fieldId: string;
    /** 日期范围选择 */
    range?: {
        from: string;
        to: string;
    };
    /** 选项值 */
    selections: string[] | [];
    /** 输入框value值 */
    value: string;
    /** 比较符号 */
    express?: string;
}
export interface ItemType {
    fieldId: string;
    fieldType: FieldType;
    fieldName: string;
    selection?: {
        label: string;
        value: string;
    }[] | null;
    type?: string;
    /** 是否在下拉选项中展示出来 */
    showOption?: boolean;
    multiSelect?: boolean;
    placeholder?: string | string[];
}
export declare type ItemsMapType = Map<string, Omit<ItemType, 'selection' | 'showOption' | 'placeholder'>>;
export interface FilterContentProps {
    /** 主标题文案 */
    filterTitle?: React.ReactNode;
    /** 主标题副文案 */
    filterSecondTitle?: React.ReactNode;
}
/** 从Form表单中获取到的数据类型 */
export declare type FieldsType = {
    fieldId: string;
    express: string;
    value: [Moment, Moment] | string | string[] | number;
}[];
