function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import React, { useContext } from 'react';
import Item from "../item";
import { getNormalDpi, sumWidths, getKey } from "../../utils/tools";
import "./index.less";
import { ExcelContext } from "../../index";
import { DataCompCxt } from "../index";

// 构建表格单元格, 需要显示的数据
var columnsBuilder = function columnsBuilder(minRow, maxRow, rowHeight, stickyWidth, dataSource) {
  var rows = [];
  var top = [0],
      pos = 0;

  for (var c = 1; c <= maxRow; c++) {
    pos += rowHeight(c - 1);
    top.push(pos);
  }

  for (var i = minRow; i <= maxRow; i++) {
    rows.push({
      style: {
        position: 'absolute',
        height: rowHeight(i),
        width: stickyWidth,
        top: top[i]
      },
      index: i,
      data: dataSource[i]
    });
  }

  return rows;
};

var StickyColumns = function StickyColumns(props) {
  var minRow = props.minRow,
      maxRow = props.maxRow,
      type = props.type,
      containerHeight = props.containerHeight; // type传值只能是left和right

  var isRight = type === 'right';

  var _ref = useContext(ExcelContext),
      columnInfo = _ref.columnInfo,
      dataSource = _ref.dataSource;

  var _ref2 = useContext(DataCompCxt),
      rowHeight = _ref2.rowHeight;

  var stickyWidth = isRight ? columnInfo.fixedRight.res : columnInfo.fixedLeft.res;

  var sideStyle = _objectSpread({
    width: stickyWidth - (!getNormalDpi() && isRight ? 1 : 0),
    height: containerHeight
  }, _defineProperty({}, type, 0));

  var sideRows = columnsBuilder(minRow, maxRow, rowHeight, stickyWidth, dataSource);
  return /*#__PURE__*/React.createElement("div", {
    className: "salaryExcelStickyColBox",
    style: sideStyle
  }, sideRows.map(function (_ref3) {
    var data = _ref3.data,
        index = _ref3.index,
        style = _ref3.style;
    return /*#__PURE__*/React.createElement("div", {
      style: style,
      key: index
    }, data.mergeArr ? data.mergeArr.map(function (v, i) {
      return /*#__PURE__*/React.createElement(RenderItem, {
        key: i,
        type: type,
        currentData: v,
        rowIndex: index,
        subRowIndex: i,
        isMergeRow: true,
        mergeData: data
      });
    }) : /*#__PURE__*/React.createElement(RenderItem, {
      type: type,
      currentData: data,
      rowIndex: index,
      subRowIndex: 0
    }));
  }));
};

var RenderItem = function RenderItem(props) {
  var type = props.type,
      currentData = props.currentData,
      rowIndex = props.rowIndex,
      subRowIndex = props.subRowIndex,
      mergeData = props.mergeData;

  var _ref4 = useContext(ExcelContext),
      columnInfo = _ref4.columnInfo,
      colData = _ref4.colData;

  var fixedLeft = columnInfo.fixedLeft,
      fixedRight = columnInfo.fixedRight;
  var sourceDate = type === 'left' ? fixedLeft : fixedRight; // type传值只能是left和right

  return /*#__PURE__*/React.createElement(React.Fragment, null, sourceDate.data.map(function (currentColumn, ii) {
    return /*#__PURE__*/React.createElement("div", {
      key: getKey(currentColumn),
      style: {
        position: 'absolute',
        left: sumWidths(sourceDate.source.slice(0, ii)),
        top: subRowIndex * colData.defaultItemHeight
      }
    }, /*#__PURE__*/React.createElement(Item, {
      rowIndex: rowIndex,
      subRowIndex: subRowIndex,
      columnIndex: ii,
      currentColumn: currentColumn,
      currentData: currentData,
      isMergeRow: true,
      mergeData: mergeData
    }));
  }));
};

export default StickyColumns;